@@ -221,6 +221,7 @@
 \\rtoe
 \\rounded-box
 \\rotate
+\\romanStringNumbers
 \\roman
 \\rightHandFinger
 \\right-column
@@ -349,6 +350,7 @@
 \\octaveCheck
 \\numericTimeSignature
 \\number
+\\nullAccidentals
 \\null
 \\notemode
 \\noteToFretFunction
@@ -461,14 +463,15 @@
 \\instrumentSwitch
 \\instrumentName
 \\instrumentEqualizer
+\\initialTimeSignatureVisibility
 \\indent
 \\include
 \\inclinatum
+\\incipit
 \\inStaffSegno
 \\in
 \\improvisationOn
 \\improvisationOff
-\\implicitTimeSignatureVisibility
 \\ij
 \\iij
 \\ignoreFiguredBassRest
@@ -522,6 +525,7 @@
 \\flat
 \\flageolet
 \\firstClef
+\\first-visible
 \\fingeringOrientations
 \\finger
 \\finalis
@@ -550,7 +554,6 @@
 \\epsfile
 \\episemInitium
 \\episemFinis
-\\endincipit
 \\enddim
 \\enddecresc
 \\enddecr
@@ -640,6 +643,7 @@
 \\context
 \\consists
 \\concat
+\\compressMMRests
 \\compressFullBarRests
 \\compoundMeter
 \\completionFactor
@@ -714,7 +718,13 @@
 \\backslashed-digit
 \\automaticBars
 \\autochange
+\\autoPageBreaksOn
+\\autoPageBreaksOff
+\\autoLineBreaksOn
+\\autoLineBreaksOff
 \\autoCautionaries
+\\autoBreaksOn
+\\autoBreaksOff
 \\autoBeaming
 \\autoBeamOn
 \\autoBeamOff
@@ -735,6 +745,7 @@
 \\arpeggioArrowUp
 \\arpeggioArrowDown
 \\arpeggio
+\\arabicStringNumbers
 \\appoggiatura
 \\applyOutput
 \\applyMusic
@@ -1062,8 +1073,6 @@ gx
 gtqs
 gtqf
 gss
-gsharpsharp
-gsharp
 gs
 gqs
 gqf
@@ -1073,8 +1082,6 @@ gisis
 gisih
 gis
 gih
-gflatflat
-gflat
 gff
 gf
 gessess
@@ -1088,8 +1095,6 @@ fx
 ftqs
 ftqf
 fss
-fsharpsharp
-fsharp
 fs
 fqs
 fqf
@@ -1099,8 +1104,6 @@ fisis
 fisih
 fis
 fih
-fflatflat
-fflat
 fff
 ff
 fessess
@@ -1137,8 +1140,6 @@ etqs
 etqf
 essess
 ess
-esharpsharp
-esharp
 eses
 eseh
 es
@@ -1150,8 +1151,6 @@ eisis
 eisih
 eis
 eih
-eflatflat
-eflat
 eff
 ef
 eessess
@@ -1165,8 +1164,6 @@ dx
 dtqs
 dtqf
 dss
-dsharpsharp
-dsharp
 ds
 dqs
 dqf
@@ -1198,8 +1195,6 @@ disis
 disih
 dis
 dih
-dflatflat
-dflat
 dff
 df
 dessess
@@ -1213,8 +1208,6 @@ cx
 ctqs
 ctqf
 css
-csharpsharp
-csharp
 cs
 cqs
 cqf
@@ -1224,8 +1217,6 @@ cisis
 cisih
 cis
 cih
-cflatflat
-cflat
 cff
 cf
 cessess
@@ -1239,8 +1230,6 @@ bx
 btqs
 btqf
 bss
-bsharpsharp
-bsharp
 bs
 bqs
 bqf
@@ -1248,8 +1237,6 @@ bisis
 bisih
 bis
 bih
-bflatflat
-bflat
 bff
 bf
 bess
@@ -1264,8 +1251,6 @@ atqs
 atqf
 assess
 ass
-asharpsharp
-asharp
 ases
 aseh
 asas
@@ -1279,8 +1264,6 @@ aisis
 aisih
 ais
 aih
-aflatflat
-aflat
 aff
 af
 aessess
